        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 24 <strong>control</strong><br>0,3,5,6,7,8,11,13,14,17,19,24,25,27,32,33,36,40,41,43,45,47,48,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 15 <br>4,10,12,15,16,18,20,29,31,34,37,39,44,46,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260618 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>21</strong> miembros: 12 <br>1,2,9,21,22,23,26,28,30,35,38,42';}
}
